@@ -3,7 +3,7 @@ package Inline::Java::Callback ;
 use strict ;
 use Carp ;
 
-$Inline::Java::Callback::VERSION = '0.48_93' ;
+$Inline::Java::Callback::VERSION = '0.48_94' ;
 
 $Inline::Java::Callback::OBJECT_HOOK = undef ;
 
@@ -145,6 +145,12 @@ sub ObjectCount {
 }
 
 
+sub __GetObjects {
+	return \%OBJECTS ;
+}
+
+
+
 ########## Utility methods used by Java to access Perl objects #################
 
 
