@@ -1,6 +1,7 @@
 package org.perl.inline.java ;
 
 import java.util.* ;
+import java.lang.reflect.* ;
 
 
 class InlineJavaClass {
@@ -469,4 +470,14 @@ class InlineJavaClass {
 
 		return false ;
 	}
+
+
+	static boolean ClassIsPublic (Class p){
+		int pub = p.getModifiers() & Modifier.PUBLIC ;
+		if (pub != 0){
+			return true ;
+		}
+
+		return false ;
+	}
 }
